//Importing Libraries
import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';

// Iris Dataset CSV link
const csvUrl = [
  'https://gist.githubusercontent.com/blikitha/d2df1d333896c98ba77a7cde6d8f308f/raw/8dd49436c00094d1ab2dbc1b22277fda79b5d3d2/iris%2520data%2520ic7', 
].join('');

const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species;
const colorValue = d => d.species;
const colorLabel = 'Species';

// Taking Height and Width 
const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Assigning colors to the scatter plot species
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){
            case 'setosa':
              return '#00cc00';
            case 'versicolor':
              return '#ff0066';
            default:
              return '#1ab2ff';
          }
        }
  
// Making range of values for x and y axis
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
// Aligning the scatter plot position
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 30,
      right: 50,
      bottom: 80,
      left: 95,
    
    })
// Size of scatter point is 6 radius
    .radius(6);
  
  
const g = svg.append('g')
    .attr('transform', `translate(${100},${100})`);

const colorLegendG = g.append('g')
    .attr('transform', `translate(${100}, 150)`);

// Defining Data Points Structure and Shape
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
// Assigning values to x and y axis
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length'*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
colorLegendG.append('text')
      .attr('class', 'legend-label')
      .attr('x', 600)
      .attr('y', 50)
      .style("font-style","Bold")
      .style("stroke","#ff3300")
      .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("Iris Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

   
// Add labels in the legend
svg.append("text").attr("x", 820).attr("y", 320).text("Setosa").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 820).attr("y", 340).text("Versicolor").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 820).attr("y", 360).text("Virginica").style("font-size", "20px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-weight","bold")
          .sty
        	.text("Sepal Length");
    
    // Add points for legend
    svg.append("circle").attr("cx",800).attr("cy",320).attr("r", 6).style("fill", "#00cc00")
		svg.append("circle").attr("cx",800).attr("cy",340).attr("r", 6).style("fill", "#ff0066")
		svg.append("circle").attr("cx",800).attr("cy",360).attr("r", 6).style("fill", "#1ab2ff")
   // plot petal_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Petal Width");
     // plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Sepal Width");
     // plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Petal Length");
     // plot sepal_length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Sepal Length");
    i++;
  }, 2000); // every 2 seconds change the visualization
};
main();



